@@ -29,6 +29,7 @@ typedef struct _GdkEventCrossing    GdkEventCrossing;
 typedef struct _GdkEventConfigure   GdkEventConfigure;
 typedef struct _GdkEventProperty    GdkEventProperty;
 typedef struct _GdkEventSelection   GdkEventSelection;
+typedef struct _GdkEventOwnerChange GdkEventOwnerChange;
 typedef struct _GdkEventProximity   GdkEventProximity;
 typedef struct _GdkEventClient	    GdkEventClient;
 typedef struct _GdkEventDND         GdkEventDND;
@@ -48,7 +49,9 @@ typedef void GdkXEvent;	  /* Can be cast to window system specific
 
 typedef enum {
   GDK_FILTER_CONTINUE,	  /* Event not handled, continue processesing */
-  GDK_FILTER_TRANSLATE,	  /* Translated event stored */
+  GDK_FILTER_TRANSLATE,	  /* Native event translated into a GDK event and
+                             stored in the "event" structure that was
+                             passed in */
   GDK_FILTER_REMOVE	  /* Terminate processing, removing event */
 } GdkFilterReturn;
 
@@ -116,7 +119,8 @@ typedef enum
   GDK_NO_EXPOSE		= 30,
   GDK_SCROLL            = 31,
   GDK_WINDOW_STATE      = 32,
-  GDK_SETTING           = 33
+  GDK_SETTING           = 33,
+  GDK_OWNER_CHANGE      = 34
 } GdkEventType;
 
 /* Event masks. (Used to select what types of events a window
@@ -205,7 +209,9 @@ typedef enum
   GDK_WINDOW_STATE_ICONIFIED  = 1 << 1,
   GDK_WINDOW_STATE_MAXIMIZED  = 1 << 2,
   GDK_WINDOW_STATE_STICKY     = 1 << 3,
-  GDK_WINDOW_STATE_FULLSCREEN = 1 << 4
+  GDK_WINDOW_STATE_FULLSCREEN = 1 << 4,
+  GDK_WINDOW_STATE_ABOVE      = 1 << 5,
+  GDK_WINDOW_STATE_BELOW      = 1 << 6
 } GdkWindowState;
 
 typedef enum
@@ -215,6 +221,13 @@ typedef enum
   GDK_SETTING_ACTION_DELETED
 } GdkSettingAction;
 
+typedef enum
+{
+  GDK_OWNER_CHANGE_NEW_OWNER,
+  GDK_OWNER_CHANGE_DESTROY,
+  GDK_OWNER_CHANGE_CLOSE
+} GdkOwnerChange;
+
 struct _GdkEventAny
 {
   GdkEventType type;
@@ -362,6 +375,18 @@ struct _GdkEventSelection
   GdkNativeWindow requestor;
 };
 
+struct _GdkEventOwnerChange
+{
+  GdkEventType type;
+  GdkWindow *window;
+  gint8 send_event;
+  GdkNativeWindow owner;
+  GdkOwnerChange reason;
+  GdkAtom selection;
+  guint32 time;
+  guint32 selection_time;
+};
+
 /* This event type will be used pretty rarely. It only is important
    for XInput aware programs that are drawing their own cursor */
 
@@ -434,6 +459,7 @@ union _GdkEvent
   GdkEventConfigure	    configure;
   GdkEventProperty	    property;
   GdkEventSelection	    selection;
+  GdkEventOwnerChange  	    owner_change;
   GdkEventProximity	    proximity;
   GdkEventClient	    client;
   GdkEventDND               dnd;
@@ -441,7 +467,7 @@ union _GdkEvent
   GdkEventSetting           setting;
 };
 
-GType     gdk_event_get_type            (void);
+GType     gdk_event_get_type            (void) G_GNUC_CONST;
 
 gboolean  gdk_events_pending	 	(void);
 GdkEvent* gdk_event_get			(void);
